import { Injectable } from '@nestjs/common';
import * as bcrypt from 'bcrypt';
import { UsersService } from '../users/users.service';
import { UserEntity } from '../entities/user.entity';
import { JwtService } from '@nestjs/jwt';

@Injectable()
export class AuthService {
  constructor(
    private readonly usersService: UsersService,
    private jwtService: JwtService,
  ) {
  }

  async validateUser(email: string, password: string): Promise<any> {
    const user = await this.usersService.findUserByEmail(email);

    if (user) {
      const checkPassword = await bcrypt.compare(password, user.password);
      return checkPassword ? { id: user.id } : null;
    }

    return null;
  }

  async getUser(user: UserEntity): Promise<UserEntity> {
    return this.usersService.findOne(user.id);
  }

  async logIn(user: any): Promise<string> {
    const payload = {
      sub: user.id,
    };

    return this.jwtService.sign(payload);
  }
}
