import { PassportStrategy } from '@nestjs/passport';
import { Strategy } from 'passport-local';
import { HttpException, Injectable } from '@nestjs/common';
import { AuthService } from './auth.service';
import { UserNotFound } from '../errors';

@Injectable()
export class LocalStrategy extends PassportStrategy(Strategy) {
  constructor(
    private authService: AuthService,
  ) {
    super({
      usernameField: 'email',
    });
  }

  async validate(email: string, password: string): Promise<any> {
    const user = await this.authService.validateUser(email, password);
    if (!user)
      throw new HttpException({
        code: 500,
        errors: [UserNotFound],
      }, 500);

    return user;
  }
}
